@@ -11,15 +11,7 @@ use base qw( Class::Factory );
 my %TYPES = ();
 sub get_factory_map { return \%TYPES }
 
-sub new {
-    my ( $class, $type, $params ) = @_;
-    my $factory_class = $class->get_factory_class( $type );
-    my $self = bless( {}, $factory_class );
-    return $self->initialize( $params );
-}
-
-
-sub initialize {
+sub init {
     my ( $self, $params ) = @_;
     $self->band_name( $params->{band_name} );
     return $self;
